aboutsummaryrefslogtreecommitdiffstats
path: root/apps/files/src/components/FileEntry/FileEntryName.vue
diff options
context:
space:
mode:
authorFerdinand Thiessen <opensource@fthiessen.de>2024-07-25 22:51:12 +0200
committernextcloud-command <nextcloud-command@users.noreply.github.com>2024-07-26 08:46:23 +0000
commitdd88fa03a41e1ead5f3c7f5333feb570683684cb (patch)
tree42804a793b1c197fd004cf7a2ed101bb9be82519 /apps/files/src/components/FileEntry/FileEntryName.vue
parent40c72d3f241a343ad0f0eb3221d0f3384a21fdeb (diff)
downloadnextcloud-server-dd88fa03a41e1ead5f3c7f5333feb570683684cb.tar.gz
nextcloud-server-dd88fa03a41e1ead5f3c7f5333feb570683684cb.zip
fix(files): Correctly validate new node name
* Resolves https://github.com/nextcloud/server/issues/45409 This includes two fixes: 1. The name in the "new node" dialog is correctly selected (e.g. `file.txt` only `file` is selected by default), to allow quick naming 2. `@nextcloud/files` functions for filename validation are used, this allows to use new Nextcloud 30 capabilities (e.g. reserved names) Signed-off-by: Ferdinand Thiessen <opensource@fthiessen.de> Signed-off-by: nextcloud-command <nextcloud-command@users.noreply.github.com>
Diffstat (limited to 'apps/files/src/components/FileEntry/FileEntryName.vue')
-rw-r--r--apps/files/src/components/FileEntry/FileEntryName.vue6
1 files changed, 3 insertions, 3 deletions
diff --git a/apps/files/src/components/FileEntry/FileEntryName.vue b/apps/files/src/components/FileEntry/FileEntryName.vue
index be491db016f..7a6ad2a1051 100644
--- a/apps/files/src/components/FileEntry/FileEntryName.vue
+++ b/apps/files/src/components/FileEntry/FileEntryName.vue
@@ -27,7 +27,7 @@
class="files-list__row-name-link"
data-cy-files-list-row-name-link
v-bind="linkTo.params">
- <!-- File name -->
+ <!-- Filename -->
<span class="files-list__row-name-text">
<!-- Keep the filename stuck to the extension to avoid whitespace rendering issues-->
<span class="files-list__row-name-" v-text="basename" />
@@ -123,7 +123,7 @@ export default defineComponent({
renameLabel() {
const matchLabel: Record<FileType, string> = {
- [FileType.File]: t('files', 'File name'),
+ [FileType.File]: t('files', 'Filename'),
[FileType.Folder]: t('files', 'Folder name'),
}
return matchLabel[this.source.type]
@@ -173,7 +173,7 @@ export default defineComponent({
watch: {
/**
* If renaming starts, select the file name
* in the input, without the extension.
* @param renaming
*/
@@ -173,7 +173,7 @@ export default defineComponent({
watch: {
/**
- * If renaming starts, select the file name
+ * If renaming starts, select the filename
* in the input, without the extension.
* @param renaming